@@ -45,4 +45,7 @@ class DropDuplicatesCodeChunk(CodeChunk):
 
         return [
             f'{df_name} = {df_name}.drop_duplicates({param_string})'
-        ]
\ No newline at end of file
+        ]
+    
+    def get_edited_sheet_indexes(self) -> List[int]:
+        return [self.get_param('sheet_index')]
\ No newline at end of file
