@@ -405,6 +405,21 @@ def make_no_analysis_error(analysis_id: str, error_modal: bool=True) -> MitoErro
         error_modal=error_modal
     )
 
+def make_invalid_promote_row_to_header(error_modal: bool=True) -> MitoError:
+    """
+    Helper function for creating a invalid_promote_row_to_header.
+
+    Occurs when a user tries to promote a row to header that has duplicated
+    values within it.
+    """
+    to_fix = f'This row has duplicated values in it. As such, making this row a header would make column references ambigious, so we cannot make it a header row.' 
+    
+    return MitoError(
+        'no_analysis_error', 
+        "Cannot create duplicate headers",
+        to_fix,
+        error_modal=error_modal
+    )
 
 ARG_FULL_NAME = {
     'int': 'number',
