@@ -4,16 +4,19 @@
 # Copyright (c) Saga Inc.
 # Distributed under the terms of the GPL License.
 
-from copy import deepcopy
 from time import perf_counter
 from typing import Any, Dict, List, Optional, Set, Tuple, Union
+from mitosheet.code_chunks.code_chunk import CodeChunk
+from mitosheet.code_chunks.empty_code_chunk import EmptyCodeChunk
+from mitosheet.code_chunks.no_op_code_chunk import NoOpCodeChunk
+from mitosheet.code_chunks.step_performers.column_steps.rename_columns_code_chunk import RenameColumnsCodeChunk
 
 from mitosheet.errors import make_column_exists_error
 from mitosheet.evaluation_graph_utils import create_column_evaluation_graph
 from mitosheet.parser import safe_replace
 from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
-from mitosheet.transpiler.transpile_utils import column_header_to_transpiled_code
+from mitosheet.step_performers.utils import get_param
 from mitosheet.types import ColumnHeader, ColumnID
 
 
@@ -35,23 +38,12 @@ class RenameColumnStepPerformer(StepPerformer):
         return 'rename_column' 
 
     @classmethod
-    def step_display_name(cls) -> str:
-        return 'Renamed a Column'
+    def execute(cls, prev_state: State, params: Dict[str, Any]) -> Tuple[State, Optional[Dict[str, Any]]]:
+        sheet_index: int = get_param(params, 'sheet_index')
+        column_id: ColumnID = get_param(params, 'column_id')
+        new_column_header: str = get_param(params, 'new_column_header')
+        level: int = get_param(params, 'new_column_header')
 
-    @classmethod
-    def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
-        return params
-
-    @classmethod
-    def execute( # type: ignore
-        cls,
-        prev_state: State,
-        sheet_index: int,
-        column_id: ColumnID,
-        new_column_header: str,
-        level=None,
-        **params
-    ) -> Tuple[State, Optional[Dict[str, Any]]]:
         if new_column_header in prev_state.dfs[sheet_index].keys():
             raise make_column_exists_error(new_column_header)
 
@@ -78,56 +70,38 @@ class RenameColumnStepPerformer(StepPerformer):
         }
 
     @classmethod
-    def transpile( # type: ignore
+    def transpile(
         cls,
         prev_state: State,
         post_state: State,
+        params: Dict[str, Any],
         execution_data: Optional[Dict[str, Any]],
-        sheet_index: int,
-        column_id: ColumnID,
-        new_column_header: str,
-        level=None
-    ) -> List[str]:
-        
-        # Process the no-op if the header is empty
-        if new_column_header == '':
-            return []
+    ) -> List[CodeChunk]:
+        if params['new_column_header'] == '':
+            # If the new column header is an empty string, it's a noop
+            return [NoOpCodeChunk(prev_state, post_state, {}, {})]
 
-        df_name = post_state.df_names[sheet_index]
-        old_column_header = prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
 
-        transpiled_old_column_header = column_header_to_transpiled_code(old_column_header)
-        transpiled_new_column_header = column_header_to_transpiled_code(new_column_header)
-        rename_dict = "{" + f'{transpiled_old_column_header}: {transpiled_new_column_header}' + "}"
-
-        rename_string = f'{df_name}.rename(columns={rename_dict}, inplace=True)'
-        return [rename_string]
-
-    @classmethod
-    def describe( # type: ignore
-        cls,
-        sheet_index: int,
-        column_id: ColumnID,
-        new_column_header: str,
-        level=None,
-        df_names=None,
-        **params
-    ) -> str:
-        if df_names is not None:
-            df_name = df_names[sheet_index]
-            return f'Renamed {column_id} to {new_column_header} in {df_name}'
-        return f'Renamed {column_id} to {new_column_header}'
+        return [
+            RenameColumnsCodeChunk(
+                prev_state, 
+                post_state, 
+                # We construct a rename for mulitple columns, as this is the most 
+                # convenient way to allow us to combine multiple renames
+                # into one
+                {
+                    'sheet_index': params['sheet_index'],
+                    'column_ids_to_new_column_headers': {
+                        params['column_id']: params['new_column_header']
+                    },
+                }, 
+                execution_data
+            )
+        ]
     
     @classmethod
-    def get_modified_dataframe_indexes( # type: ignore
-        cls, 
-        sheet_index: int,
-        column_id: ColumnID,
-        new_column_header: str,
-        level=None,
-        **params
-    ) -> Set[int]:
-        return {sheet_index}
+    def get_modified_dataframe_indexes(cls, params: Dict[str, Any]) -> Set[int]:
+        return {get_param(params, 'sheet_index')}
 
 
 def rename_column_headers_in_state(
@@ -135,7 +109,7 @@ def rename_column_headers_in_state(
         sheet_index: int,
         column_id: ColumnID,
         new_column_header: ColumnHeader,
-        level: Union[None, int]
+        level: Optional[int]=None
     ) -> Tuple[Optional[ColumnHeader], float]:
     """
     A helper function for updating a column header in the state, which is useful
@@ -161,7 +135,7 @@ def rename_column_headers_in_state(
             new_column_header,
             original_column_headers
         )
-
+    
     # Update the column header
     pandas_start_time = perf_counter()
     post_state.column_ids.set_column_header(sheet_index, column_id, new_column_header)
