@@ -4,6 +4,7 @@
 # Copyright (c) Saga Inc.
 # Distributed under the terms of the GPL License.
 from abc import ABC, abstractmethod
+from mitosheet.code_chunks.code_chunk import CodeChunk
 from mitosheet.state import State
 from typing import Any, Dict, List, Optional, Set, Tuple
  
@@ -30,26 +31,17 @@ class StepPerformer(ABC, object):
         the step and bump the version.
         """
         pass
-
-    @classmethod
-    @abstractmethod
-    def step_display_name(cls) -> str:
-        """
-        The name of the step that is displayed to the user
-        in the frontend.
-        """
-        pass
     
     @classmethod
-    @abstractmethod
     def step_event_type(cls) -> str:
         """
-        The type of the edit event that generates this type of step.
+        The type of the edit event that generates this type of step. 
+        This is always just f'{cls.step_type}_edit'.
         """
-        pass
+        return f'{cls.step_type()}_edit'
 
     @classmethod
-    def saturate(cls, prev_state: State, params: Any) -> Dict[str, str]:
+    def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
         """
         Given the parameters of the step, will saturate the event with
         more parameters based on the passed prev_state. 
@@ -59,35 +51,39 @@ class StepPerformer(ABC, object):
 
     @classmethod
     @abstractmethod
-    def execute(cls, prev_state: State, **params: Any) -> Tuple[State, Optional[Dict[str, Any]]]:
+    def execute(cls, prev_state: State, params: Dict[str, Any]) -> Tuple[State, Optional[Dict[str, Any]]]:
         """
         Execute always returns the post_state, and optionally returns a dictionary
         of execution_data, which is data that may be useful to the transpiler in
         transpiling the code.
+
+        If the execution_data also includes the key `pandas_processing_time`, this 
+        will allow the logging infrastructure to determine how much overhead Mito
+        adds to executing this event.
+
+        If the exectution_data includes the key `result`, than this result can be
+        accessed in the frontend to display some results to the user. See the 
+        DropDuplicatesStepPerformer and the DropDuplicatesCodeChunk for an example of this usage.
+        """
+        pass
+
+    @classmethod
+    def transpile(
+        cls,
+        prev_state: State,
+        post_state: State,
+        params: Dict[str, Any],
+        execution_data: Optional[Dict[str, Any]],
+    ) -> List[CodeChunk]:
+        """
+        Returns a list of the CodeChunks that correspond to this 
+        step being executed
         """
         pass
 
     @classmethod
     @abstractmethod
-    def transpile(cls, prev_state: State, post_state: State, **params: Any) -> List[str]:
-        """
-        Returns a list of the Python code lines that corresponds to this 
-        step being executed.
-        """
-        pass
-
-    @classmethod
-    @abstractmethod
-    def describe(cls, **params: Any) -> str:
-        """
-        Describes the step in a single sentence, usually for comments or for presentation
-        to the user in the frontend.
-        """
-        pass
-
-    @classmethod
-    @abstractmethod
-    def get_modified_dataframe_indexes(cls, **params: Any) -> Set[int]:
+    def get_modified_dataframe_indexes(cls, params: Dict[str, Any]) -> Set[int]:
         """
         Returns a set of all the sheet indexes that were modified
         by this step.
