@@ -5,24 +5,30 @@
 # Distributed under the terms of the GPL License.
 
 import json
+import random
+import string
 import uuid
 from copy import copy, deepcopy
-import pandas as pd
-from typing import Any, Dict, Collection, List, Set, Tuple, Union
-from mitosheet.mito_analytics import log
+from typing import Any, Collection, Dict, List, Set, Tuple, Union
 
-from mitosheet.step_performers.import_steps.simple_import import (
-    SimpleImportStepPerformer,
-)
-from mitosheet.step_performers.import_steps.excel_import import ExcelImportStepPerformer
+import pandas as pd
+
+from mitosheet.data_in_mito import DataTypeInMito, get_data_type_in_mito
+from mitosheet.telemetry.telemetry_utils import log
+from mitosheet.preprocessing import PREPROCESS_STEP_PERFORMERS
+from mitosheet.saved_analyses.save_utils import get_analysis_exists
 from mitosheet.state import State
 from mitosheet.step import Step
 from mitosheet.step_performers import EVENT_TYPE_TO_STEP_PERFORMER
-from mitosheet.updates import UPDATES
-from mitosheet.preprocessing import PREPROCESS_STEP_PERFORMERS
-from mitosheet.utils import dfs_to_array_for_json, get_new_id, is_default_df_names
+from mitosheet.step_performers.import_steps.excel_import import \
+    ExcelImportStepPerformer
+from mitosheet.step_performers.import_steps.simple_import import \
+    SimpleImportStepPerformer
 from mitosheet.transpiler.transpile import transpile
-from mitosheet.data_in_mito import DataTypeInMito, get_data_type_in_mito
+from mitosheet.updates import UPDATES
+from mitosheet.user.utils import is_pro, is_running_test
+from mitosheet.utils import (NpEncoder, dfs_to_array_for_json, get_new_id,
+                             is_default_df_names)
 
 
 def get_step_indexes_to_skip(step_list: List[Step]) -> Set[int]:
@@ -100,9 +106,7 @@ def get_modified_sheet_indexes(
     # otherwise we just say all of them (undo, replay might interact weird)
     if starting_step_index == ending_step_index - 1:
         step = steps[ending_step_index]
-        modified_indexes = step.step_performer.get_modified_dataframe_indexes(
-            **step.params
-        )
+        modified_indexes = step.step_performer.get_modified_dataframe_indexes(step.params)
 
         # If the set is empty, then we modified everything
         if len(modified_indexes) == 0:
@@ -157,7 +161,7 @@ class StepsManager:
     and parameters stay the same and are append-only.
     """
 
-    def __init__(self, args: Collection[Union[pd.DataFrame, str]]):
+    def __init__(self, args: Collection[Union[pd.DataFrame, str]], analysis_to_replay: str=None):
         """
         When initalizing the StepsManager, we also do preprocessing
         of the arguments that were passed to the mitosheet.
@@ -165,9 +169,13 @@ class StepsManager:
         All preprocessing can be found in mitosheet/preprocessing, and each of
         the transformations are applied before the data is considered imported.
         """
-        # We just randomly generate analysis names.
-        # We append a UUID to note that this is not an analysis the user has saved.
-        self.analysis_name = "UUID-" + str(uuid.uuid4())
+        # We just randomly generate analysis names as a string of 10 letters
+        self.analysis_name = 'id-' + ''.join(random.choice(string.ascii_lowercase) for _ in range(10))
+
+        # We also save some data about the analysis the user wants to replay, if there
+        # is such an analysis
+        self.analysis_to_replay = analysis_to_replay
+        self.analysis_to_replay_exists = get_analysis_exists(analysis_to_replay)
 
         # The args are a tuple of dataframes or strings, and we start by making them
         # into a list, and making copies of them for safe keeping
@@ -224,6 +232,12 @@ class StepsManager:
         # which allows us to have some awareness about undos and redos in the front-end
         self.update_event_count = 0
 
+        # This stores the number of times that the sheet renders, and we use it to detect
+        # when we are on the first render of a sheet. This is very useful for making
+        # sure we only update the state of the backend on the first render of a sheet
+        # that corresponds to that backend
+        self.render_count = 0
+
     @property
     def curr_step(self) -> Step:
         """
@@ -269,19 +283,25 @@ class StepsManager:
         self.saved_sheet_data = array
         self.last_step_index_we_wrote_sheet_json_on = self.curr_step_idx
 
-        return json.dumps(array)
+        return json.dumps(array, cls=NpEncoder)
 
     @property
     def analysis_data_json(self):
         return json.dumps(
             {
                 "analysisName": self.analysis_name,
-                "code": transpile(self),
+                "analysisToReplay": {
+                    'analysisName': self.analysis_to_replay,
+                    'existsOnDisk': self.analysis_to_replay_exists,
+                } if self.analysis_to_replay is not None else None,
+                "code": transpile(self, optimize=(is_pro() or is_running_test())),
                 "stepSummaryList": self.step_summary_list,
                 "currStepIdx": self.curr_step_idx,
                 "dataTypeInTool": self.data_type_in_mito.value,
                 "graphDataDict": self.curr_step.graph_data_dict,
                 'updateEventCount': self.update_event_count,
+                'renderCount': self.render_count,
+                'lastResult': self.curr_step.execution_data['result'] if 'result' in self.curr_step.execution_data else None
             }
         )
 
@@ -308,17 +328,23 @@ class StepsManager:
 
             if index in step_indexes_to_skip:
                 continue
+            
+            # NOTE: we cannot and should not optimize the code chunks here, as
+            # rely on getting data out of them is to label the steps correctly
+            code_chunks = step.step_performer.transpile(
+                step.prev_state, # type: ignore
+                step.post_state, # type: ignore
+                step.params,
+                step.execution_data,
+            )
 
             step_summary_list.append(
                 {
                     "step_id": step.step_id,
                     "step_idx": index,
                     "step_type": step.step_type,
-                    "step_display_name": step.step_performer.step_display_name(),
-                    "step_description": step.step_performer.describe(
-                        df_names=step.df_names,
-                        **step.params,
-                    ),
+                    "step_display_name": code_chunks[0].get_display_name(),
+                    "step_description": code_chunks[0].get_description_comment(),
                 }
             )
 
@@ -371,7 +397,7 @@ class StepsManager:
         for update in UPDATES:
             if update_event["type"] == update["event_type"]:
                 # Get the params for this event
-                params = {key: value for key, value in update_event.items() if key in update["params"]}  # type: ignore
+                params = {key: value for key, value in update_event['params'].items() if key in update['params']}  # type: ignore
                 # Actually execute this event
                 update["execute"](self, **params)  # type: ignore
                 # Update the number of update events we record occuring
