@@ -30,6 +30,11 @@ pandas_post_1_2_only = pytest.mark.skipif(
     reason='This test only runs on later versions of Pandas. API inconsistencies make it fail on earlier versions'
 )
 
+pandas_post_1_4_only = pytest.mark.skipif(
+    is_prev_version(pd.__version__, '1.4.0'), 
+    reason='This test only runs on later versions of Pandas. API inconsistencies make it fail on earlier versions'
+)
+
 pandas_pre_1_2_only = pytest.mark.skipif(
     not is_prev_version(pd.__version__, '1.2.0'), 
     reason='This test only runs on later versions of Pandas. API inconsistencies make it fail on earlier versions'
