@@ -33,9 +33,13 @@ from mitosheet.step_performers import (
     GraphStepPerformer,
     ConcatStepPerformer
 )
+from mitosheet.step_performers.delete_row import DeleteRowStepPerformer
+from mitosheet.step_performers.column_steps.split_text_to_columns import SplitTextToColumnsStepPerformer
+from mitosheet.step_performers.fill_na import FillNaStepPerformer
 from mitosheet.step_performers.graph_steps.graph_delete import GraphDeleteStepPerformer
 from mitosheet.step_performers.graph_steps.graph_duplicate import GraphDuplicateStepPerformer
 from mitosheet.step_performers.graph_steps.graph_rename import GraphRenameStepPerformer
+from mitosheet.step_performers.promote_row_to_header import PromoteRowToHeaderStepPerformer
 
 def check_step(
         step_performer: StepPerformer, 
@@ -216,7 +220,31 @@ def test_params_static():
         'concat'
     )
 
-    assert len(STEP_PERFORMERS) == 24
+    check_step(
+        FillNaStepPerformer,
+        1,
+        'fill_na'
+    )
+
+    check_step(
+        DeleteRowStepPerformer,
+        1,
+        'delete_row'
+    )
+
+    check_step(
+        PromoteRowToHeaderStepPerformer,
+        1,
+        'promote_row_to_header'
+    )
+
+    check_step(
+        SplitTextToColumnsStepPerformer,
+        1,
+        'split_text_to_columns'
+    )
+
+    assert len(STEP_PERFORMERS) == 28
 
 
 def get_fake_param(param_name):
