@@ -19,7 +19,7 @@ from mitosheet.mito_widget import MitoWidget, sheet
 from mitosheet.parser import parse_formula
 from mitosheet.transpiler.transpile import transpile
 from mitosheet.types import ColumnHeader, ColumnID, GraphID, MultiLevelColumnHeader
-from mitosheet.utils import dfs_to_array_for_json, get_new_id
+from mitosheet.utils import NpEncoder, dfs_to_array_for_json, get_new_id
 
 
 def decorate_all_functions(function_decorator):
@@ -107,7 +107,7 @@ def check_dataframes_equal(test_wrapper):
         test_wrapper.mito_widget.steps_manager.curr_step.column_filters,
         test_wrapper.mito_widget.steps_manager.curr_step.column_ids,
         test_wrapper.mito_widget.steps_manager.curr_step.column_format_types
-    ))
+    ), cls=NpEncoder)
 
 
 class MitoWidgetTestWrapper:
@@ -281,6 +281,109 @@ class MitoWidgetTestWrapper:
                 }
             }
         )
+    
+    @check_transpiled_code_after_call
+    def fill_na(
+            self, 
+            sheet_index: int,
+            column_headers: List[ColumnHeader],
+            fill_method: Any
+        ) -> bool:
+
+        column_ids = [
+            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index, column_header)
+            for column_header in column_headers
+        ]
+
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'fill_na_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'sheet_index': sheet_index,
+                    'column_ids': column_ids,
+                    'fill_method': fill_method
+                }
+            }
+        )
+
+    
+    @check_transpiled_code_after_call
+    def delete_row(
+            self, 
+            sheet_index: int,
+            labels: List[Union[int, str]],
+        ) -> bool:        
+
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'delete_row_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'sheet_index': sheet_index,
+                    'labels': labels,
+                }
+            }
+        )
+    
+
+    @check_transpiled_code_after_call
+    def promote_row_to_header(
+            self, 
+            sheet_index: int,
+            index: Any,
+        ) -> bool:
+        
+
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'promote_row_to_header_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'sheet_index': sheet_index,
+                    'index': index,
+                    
+                }
+            }
+        )
+    
+# AUTOGENERATED LINE: TEST (DO NOT DELETE)
+
+    @check_transpiled_code_after_call
+    def split_text_to_columns(
+            self, 
+            sheet_index: int,
+            column_header: ColumnHeader,
+            delimiters: List[str],
+            new_column_header_suffix: str
+        ) -> bool:
+
+        column_id = self.mito_widget.steps_manager.curr_step.get_column_id_by_header(sheet_index, column_header)
+
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'split_text_to_columns_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'sheet_index': sheet_index,
+                    'column_id': column_id,
+                    'delimiters': delimiters,
+                    'new_column_header_suffix': new_column_header_suffix
+                }
+            }
+        )
 
     @check_transpiled_code_after_call
     def drop_duplicates(
@@ -1049,4 +1152,4 @@ def make_multi_index_header_df(data: Dict[Union[str, int], List[Any]], column_he
     df.columns = pd.MultiIndex.from_tuples(final_column_headers)
     if index is not None:
         df.index = index
-    return df
+    return df
\ No newline at end of file
